@@ -62,11 +62,14 @@ class Firewall(PanDevice):
         "device.Vsys",
         "device.VsysResources",
         "device.SystemSettings",
+        "device.LogSettingsSystem",
+        "device.LogSettingsConfig",
         "device.PasswordProfile",
         "device.Administrator",
         "device.Telemetry",
         "device.SnmpServerProfile",
         "device.EmailServerProfile",
+        "device.LdapServerProfile",
         "device.SyslogServerProfile",
         "device.HttpServerProfile",
         "ha.HighAvailability",
@@ -83,6 +86,7 @@ class Firewall(PanDevice):
         "objects.LogForwardingProfile",
         "objects.DynamicUserGroup",
         "objects.Region",
+        "objects.Edl",
         "policies.Rulebase",
         "network.EthernetInterface",
         "network.AggregateInterface",
